@@ -35,6 +35,7 @@
 #include "playlist_jump.h"
 #include "playlist_addurl.h"
 #include "settings.h"
+#include "playlist_create.h"
 
 static gchar* playing_status(void);
 void mainwin_repaint(void);
@@ -276,19 +277,19 @@ static void controls(gint c)
 			playlist_paint(&list);
 			break;
 		case 'd':
-			if((list.selector >= 0) && (audacious_remote_get_playlist_length(dbus_proxy) > 0))
-			{
-				audacious_remote_playlist_delete(dbus_proxy, list.selector);
-				--(list.selector);
-			}
+			if( (list.selector >= 0) && (audacious_remote_get_playlist_length(dbus_proxy) > 0))
+                        {
+                            audacious_remote_playlist_delete(dbus_proxy, list.selector);
+                        }
 			if(list.selector<0)
 				list.selector = 0;
-			if((int) audacious_remote_get_playlist_length(dbus_proxy) > 0)
-			{
-				playlist_read(audacious_remote_get_playlist_length(dbus_proxy));
-				playlist_paint(&list);
-			}
+			playlist_read(audacious_remote_get_playlist_length(dbus_proxy));
+			playlist_paint(&list);
 			break;
+                case 'u':
+                case 'U':
+                        playlist_create();
+                        break;
 	}
 }
 
