@@ -134,7 +134,7 @@ void playlist_read(gint length)
 	list.song = (song*) realloc(list.song, sizeof(song)*length);
 	for (i=0; i<length; i++) {
 		list.song[i].file =  audacious_remote_get_playlist_file(dbus_proxy, i);
-		list.song[i].title = malloc(sizeof(char));
+		list.song[i].title = malloc(sizeof(gchar));
 		list.song[i].title=g_strdup("");
 		list.song[i].length = 0;
 		if (settings.read_all) {
